@@ -207,11 +207,16 @@ class ActivateFile(BinFile):
 
     """The virtual environment /bin/activate script."""
 
-    read_pattern = re.compile(r'''^VIRTUAL_ENV=["'](.*)["']$''')
-    write_pattern = 'VIRTUAL_ENV=\'{0}\''
+    read_pattern = re.compile(r"""^VIRTUAL_ENV=["'](.*)["']$""")
 
     def _find_vpath(self):
-        """Find the VIRTUAL_ENV path entry."""
+        """
+        Find the VIRTUAL_ENV path entry.
+
+        Returns:
+            tuple: A tuple containing the matched line, the old vpath, and the line number where the virtual
+            path was found. If the virtual path is not found, returns a tuple of three None values.
+        """
         with open(self.path, "r") as file_handle:
 
             for count, line in enumerate(file_handle):
@@ -219,45 +224,95 @@ class ActivateFile(BinFile):
                 match = self.read_pattern.match(line)
                 if match:
 
-                    return match.group(1), count
+                    return match.group(0), match.group(1), count
 
-        return None, None
+        return None, None, None
 
     @property
     def vpath(self):
         """Get the path to the virtual environment."""
-        return self._find_vpath()[0]
+        return self._find_vpath()[1]
 
     @vpath.setter
     def vpath(self, new_vpath):
         """Change the path to the virtual environment."""
-        _, line_number = self._find_vpath()
-        new_vpath = self.write_pattern.format(new_vpath)
-        self.writeline(new_vpath, line_number)
+        old_line, old_vpath, line_number = self._find_vpath()
+        new_line = old_line.replace(old_vpath, new_vpath)
+        self.writeline(new_line, line_number)
 
 
 class ActivateFishFile(ActivateFile):
 
     """The virtual environment /bin/activate.fish script."""
 
-    read_pattern = re.compile(r'''^set -gx VIRTUAL_ENV ["'](.*)["']$''')
-    write_pattern = 'set -gx VIRTUAL_ENV \'{0}\''
+    read_pattern = re.compile(r"""^set -gx VIRTUAL_ENV ["'](.*)["']$""")
 
 
 class ActivateCshFile(ActivateFile):
 
     """The virtual environment /bin/activate.csh script."""
 
-    read_pattern = re.compile(r'''^setenv VIRTUAL_ENV ["'](.*)["']$''')
-    write_pattern = 'setenv VIRTUAL_ENV \'{0}\''
+    read_pattern = re.compile(r"""^setenv VIRTUAL_ENV ["'](.*)["']$""")
 
 
 class ActivateXshFile(ActivateFile):
 
     """The virtual environment /bin/activate.xsh script."""
 
-    read_pattern = re.compile(r'''^\$VIRTUAL_ENV = r["'](.*)["']$''')
-    write_pattern = '$VIRTUAL_ENV = r"{0}"'
+    read_pattern = re.compile(r"""^\$VIRTUAL_ENV = r["'](.*)["']$""")
+
+
+class ActivateNuFile(ActivateFile):
+
+    """The virtual environment /bin/activate.nu script.
+
+    Note that the NU shell activation script is different from previously
+    supported shells because it contains two references to the virtualenv path
+    rather than one. This is because it requires a specialized deactivate
+    script which is aliased to the deactivate command.
+
+    activate.nu:3 generated with virtualenv 20.13.3
+    let virtual-env = "/tmp/test_venv"
+
+    activate.nu:34 generated with virtualenv 20.21.0
+    ....let virtual_env = '/tmp/test_venv'
+    """
+
+    read_pattern = re.compile(r"""^\s*let virtual[-_]env = ["'](.*)["']$""")
+
+
+class ActivateNuFileDeactivateAlias(ActivateFile):
+
+    """The virtual environment /bin/activate.nu script's deactivate alias.
+
+    This is the second part of the NU shell activation script modification
+    This is implemented as a second activate script as a convenience. The
+    ActivateFile base class only ever expected that a single line in the
+    activate script would contain the virtualenv path. NU shell is the first
+    script to break that expectation. Rather than re-write the ActivateFile
+    class, this class models the second line containing the path as a second
+    file in order to use the inherited regex matching logic.
+    """
+
+    read_pattern = re.compile(
+        r"""^alias deactivate = source ["'](.*)/bin/deactivate.nu["']$"""
+    )
+
+    @property
+    def exists(self):
+        """
+        Get if the path exists.
+
+        Overwite VenvPath property. The /bin/activate.nu scipt generated
+        by virtualenv>=20.14.0 does contain a virtual path anymore.
+        So, relocation is only required for older versions.
+
+        Returns:
+            bool: True if the /bin/activate.nu exists and it contains a virtual path
+                  for deactivate.
+        """
+
+        return os.path.exists(self.path) and self.vpath is not None
 
 
 class BinDir(VenvDir):
@@ -274,6 +329,8 @@ class BinDir(VenvDir):
                 self.activate_csh,
                 self.activate_fish,
                 self.activate_xsh,
+                self.activate_nu,
+                self.activate_nu_deactivate,
             )
             if activation.exists
         )
@@ -298,6 +355,26 @@ class BinDir(VenvDir):
         """Get the /bin/activate.xsh script."""
         return ActivateXshFile(os.path.join(self.path, "activate.xsh"))
 
+    @property
+    def activate_nu(self):
+        """Get the /bin/activate.nu script."""
+        return ActivateNuFile(os.path.join(self.path, "activate.nu"))
+
+    @property
+    def activate_nu_deactivate(self):
+        """Get the /bin/activate.nu script.
+
+        This returns the same underlying file as the activate_nu property but
+        is configured to target all vpath operations to the secondary
+        virtualenv path reference that exists to set up the deactivate
+        command. Generally, any use of the activate_nu property to modify the
+        vpath must be repeated with this property as well. See the
+        ActivateNuFileDeactivateAlias class documentation for more information.
+        """
+        return ActivateNuFileDeactivateAlias(
+            os.path.join(self.path, "activate.nu")
+        )
+
     @property
     def files(self):
         """Get an iter of VenvFiles within the directory."""
